import { createApp } from 'vue/dist/vue.esm-bundler'
import { createStore } from 'vuex'
import App from './App.vue'
import router from './router/routes.js'

const store = createStore({
    state () {
        return {
            Session: {
                Token: null,
                User: null
            },
            Budgets: [],
            CurrentBudget: null,
        }
    },
    mutations: {
        initializeStore(state) {
            let store = localStorage.getItem("store");
            if(store){
                this.replaceState(
                    Object.assign(state, JSON.parse(store))
                );
            }
        },
        getDashboard (state) {
            fetch("/api/v1/dashboard", {
                headers: {
                    'Authorization': 'Bearer ' + state.Session.Token
                }
            })
                .then(x => x.json())
                .then(x => state.Budgets = x.Budgets)
                .then(x => console.log(state.Budgets));
        },
        setTitle (state, title) {
            document.title = "Budgeteer - " + title;
        },
        setToken(state, token) {
            state.Session.Token = token;
        }
    }
})

store.subscribe((mutation, state) => {
    let persistedState = {
        Session: state.Session,
        Budgets: state.Budgets,
        CurrentBudget: state.CurrentBudget
    }
    localStorage.setItem("store", JSON.stringify(persistedState));
})

const app = createApp(App)
app.use(router)
app.use(store)
app.mount('#app')
